==> dojo_1.11.0+dfsg.orig.tar.gz: dojo-release-1.11.0-src/dojo/cldr/nls/zh/chinese.js <==
define(
//begin v1.x content
{
	"months-format-narrow": [
		"正",
		"二",
		"三",
		"四",
		"五",
		"六",
		"七",
		"八",
		"九",
		"十",
		"冬",
		"腊"
	],
	"field-second-relative+0": "现在",
	"field-weekday": "星期",
	"field-wed-relative+0": "本周三",
	"field-wed-relative+1": "下周三",
	"dateFormatItem-GyMMMEd": "U年MMMd日E",
	"dateFormatItem-MMMEd": "MMMd日E",
	"field-tue-relative+-1": "上周二",
	"dateFormat-long": "U年MMMd",
	"field-fri-relative+-1": "上周五",
	"field-wed-relative+-1": "上周三",
	"months-format-wide": [
		"正月",
		"二月",
		"三月",
		"四月",
		"五月",
		"六月",
		"七月",
		"八月",
		"九月",
		"十月",
		"冬月",
		"腊月"
	],
	"dateFormatItem-yyyyQQQ": "U年QQQQ",
	"dateFormat-full": "U年MMMdEEEE",
	"dateFormatItem-yyyyMEd": "U年MMMd日，E",
	"field-thu-relative+-1": "上周四",
	"dateFormatItem-Md": "M-d",
	"dateFormatItem-yMd": "U年MMMd日",
	"field-era": "纪元",
	"months-standAlone-wide": [
		"正月",
		"二月",
		"三月",
		"四月",
		"五月",
		"六月",
		"七月",
		"八月",
		"九月",
		"十月",
		"冬月",
		"腊月"
	],
	"field-year": "年",
	"field-hour": "小时",
	"months-format-abbr": [
		"正月",
		"二月",
		"三月",
		"四月",
		"五月",
		"六月",
		"七月",
		"八月",
		"九月",
		"十月",
		"冬月",
		"腊月"
	],
	"field-sat-relative+0": "本周六",
	"field-sat-relative+1": "下周六",
	"field-day-relative+0": "今天",
	"field-thu-relative+0": "本周四",
	"field-day-relative+1": "明天",
	"field-thu-relative+1": "下周四",
	"dateFormatItem-GyMMMd": "U年MMMd日",
	"field-day-relative+2": "后天",
	"months-standAlone-abbr": [
		"正月",
		"二月",
		"三月",
		"四月",
		"五月",
		"六月",
		"七月",
		"八月",
		"九月",
		"十月",
		"冬月",
		"腊月"
	],
	"dateFormatItem-Gy": "U年",
	"dateFormatItem-yyyyMMMEd": "U年MMMd日E",
	"dateFormatItem-M": "MMM",
	"dateFormatItem-yyyyMMM": "U年MMM",
	"dateFormatItem-yyyyMMMd": "U年MMMd日",
	"field-sun-relative+0": "本周日",
	"field-sun-relative+1": "下周日",
	"field-minute": "分钟",
	"field-dayperiod": "上午/下午",
	"dateFormatItem-d": "d日",
	"field-day-relative+-1": "昨天",
	"field-day-relative+-2": "前天",
	"dateFormatItem-MMMd": "MMMd日",
	"dateFormatItem-MEd": "M-dE",
	"field-fri-relative+0": "本周五",
	"field-fri-relative+1": "下周五",
	"field-day": "日",
	"field-zone": "时区",
	"dateFormatItem-y": "U年",
	"months-standAlone-narrow": [
		"正",
		"二",
		"三",
		"四",
		"五",
		"六",
		"七",
		"八",
		"九",
		"十",
		"冬",
		"腊"
	],
	"field-year-relative+-1": "去年",
	"field-month-relative+-1": "上个月",
	"dateFormatItem-yyyyMd": "U年MMMd日",
	"field-month": "月",
	"field-tue-relative+0": "本周二",
	"field-tue-relative+1": "下周二",
	"field-mon-relative+0": "本周一",
	"field-mon-relative+1": "下周一",
	"dateFormat-short": "U-M-d",
	"field-second": "秒钟",
	"field-sat-relative+-1": "上周六",
	"field-sun-relative+-1": "上周日",
	"field-month-relative+0": "本月",
	"field-month-relative+1": "下个月",
	"dateFormatItem-Ed": "d日E",
	"field-week": "周",
	"dateFormat-medium": "U年MMMd",
	"field-year-relative+0": "今年",
	"field-week-relative+-1": "上周",
	"dateFormatItem-yyyyM": "U年MMM",
	"field-year-relative+1": "明年",
	"dateFormatItem-yyyyQQQQ": "U年QQQQ",
	"dateFormatItem-GyMMM": "U年MMM",
	"field-mon-relative+-1": "上周一",
	"dateFormatItem-yyyy": "U年",
	"field-week-relative+0": "本周",
	"field-week-relative+1": "下周"
}
//end v1.x content
);

==> dojo_1.14.2+dfsg1.orig.tar.gz: dojo-release-1.14.2-src/dojo/cldr/nls/zh/chinese.js <==
define(
//begin v1.x content
{
	"months-format-narrow": [
		"正",
		"二",
		"三",
		"四",
		"五",
		"六",
		"七",
		"八",
		"九",
		"十",
		"冬",
		"腊"
	],
	"field-second-relative+0": "现在",
	"field-weekday": "工作日",
	"field-wed-relative+0": "本周三",
	"field-wed-relative+1": "下周三",
	"dateFormatItem-GyMMMEd": "rU年MMMdE",
	"dateFormatItem-MMMEd": "MMMd日E",
	"field-tue-relative+-1": "上周二",
	"dateFormat-long": "rU年MMMd",
	"field-fri-relative+-1": "上周五",
	"field-wed-relative+-1": "上周三",
	"months-format-wide": [
		"正月",
		"二月",
		"三月",
		"四月",
		"五月",
		"六月",
		"七月",
		"八月",
		"九月",
		"十月",
		"冬月",
		"腊月"
	],
	"dateFormatItem-yyyyQQQ": "rU年QQQQ",
	"dateFormat-full": "rU年MMMdEEEE",
	"dateFormatItem-yyyyMEd": "rU年MMMd，E",
	"field-thu-relative+-1": "上周四",
	"dateFormatItem-Md": "M-d",
	"dateFormatItem-yMd": "r年MMMd",
	"field-era": "纪元",
	"months-standAlone-wide": [
		"正月",
		"二月",
		"三月",
		"四月",
		"五月",
		"六月",
		"七月",
		"八月",
		"九月",
		"十月",
		"冬月",
		"腊月"
	],
	"field-year": "年",
	"field-hour": "小时",
	"months-format-abbr": [
		"正月",
		"二月",
		"三月",
		"四月",
		"五月",
		"六月",
		"七月",
		"八月",
		"九月",
		"十月",
		"冬月",
		"腊月"
	],
	"field-sat-relative+0": "本周六",
	"field-sat-relative+1": "下周六",
	"field-day-relative+0": "今天",
	"field-thu-relative+0": "本周四",
	"field-day-relative+1": "明天",
	"field-thu-relative+1": "下周四",
	"dateFormatItem-GyMMMd": "r年MMMd",
	"field-day-relative+2": "后天",
	"months-standAlone-abbr": [
		"正月",
		"二月",
		"三月",
		"四月",
		"五月",
		"六月",
		"七月",
		"八月",
		"九月",
		"十月",
		"冬月",
		"腊月"
	],
	"dateFormatItem-Gy": "rU年",
	"dateFormatItem-yyyyMMMEd": "rU年MMMdE",
	"dateFormatItem-M": "MMM",
	"dateFormatItem-yyyyMMM": "rU年MMM",
	"dateFormatItem-yyyyMMMd": "r年MMMd",
	"field-sun-relative+0": "本周日",
	"field-sun-relative+1": "下周日",
	"field-minute": "分钟",
	"field-dayperiod": "上午/下午",
	"dateFormatItem-d": "d日",
	"field-day-relative+-1": "昨天",
	"field-day-relative+-2": "前天",
	"dateFormatItem-MMMd": "MMMd日",
	"dateFormatItem-MEd": "M-dE",
	"field-fri-relative+0": "本周五",
	"field-fri-relative+1": "下周五",
	"field-day": "日",
	"field-zone": "时区",
	"dateFormatItem-y": "rU年",
	"months-standAlone-narrow": [
		"正",
		"二",
		"三",
		"四",
		"五",
		"六",
		"七",
		"八",
		"九",
		"十",
		"冬",
		"腊"
	],
	"field-year-relative+-1": "去年",
	"field-month-relative+-1": "上个月",
	"dateFormatItem-yyyyMd": "r年MMMd",
	"field-month": "月",
	"field-tue-relative+0": "本周二",
	"field-tue-relative+1": "下周二",
	"field-mon-relative+0": "本周一",
	"field-mon-relative+1": "下周一",
	"dateFormat-short": "r-M-d",
	"field-second": "秒钟",
	"field-sat-relative+-1": "上周六",
	"field-sun-relative+-1": "上周日",
	"field-month-relative+0": "本月",
	"field-month-relative+1": "下个月",
	"dateFormatItem-Ed": "d日E",
	"field-week": "周",
	"dateFormat-medium": "r年MMMd",
	"field-year-relative+0": "今年",
	"field-week-relative+-1": "上周",
	"dateFormatItem-yyyyM": "rU年MMM",
	"field-year-relative+1": "明年",
	"dateFormatItem-yyyyQQQQ": "rU年QQQQ",
	"dateFormatItem-GyMMM": "rU年MMM",
	"field-mon-relative+-1": "上周一",
	"dateFormatItem-yyyy": "rU年",
	"field-week-relative+0": "本周",
	"field-week-relative+1": "下周"
}
//end v1.x content
);
